from distutils.core import setup

setup(
    name         = 'nepster',
    version      = '1.0.0',
    py_modules   = ['nepster'],
    author       = 'test',
    author_email = 'test@test.com',
    url          = 'www.test.com',
    description  = 'A simple world here',
)